@@ -334,31 +334,40 @@ class SugarJar
         curr = current_branch
         base = tracked_branch
         if @pr_autofill
+          SugarJar::Log.info('Autofilling in PR from commit message')
           num_commits = git(
             'rev-list', '--count', curr, "^#{base}"
           ).stdout.strip.to_i
           if num_commits > 1
-            SugarJar::Log.debug(
-              "Not using --fill because there are #{num_commits} commits",
-            )
+            args.unshift('--fill-first')
           else
-            SugarJar::Log.info('Autofilling in PR from commit message')
             args.unshift('--fill')
           end
         end
         if subfeature?(base)
+          if upstream != push_org
+            SugarJar::Log.warn(
+              'Unfortunately you cannot based one PR on another PR when' +
+              " using fork-based PRs. We will base this on #{most_main}." +
+              ' This just means the PR "Changes" tab will show changes for' +
+              ' the full stack until those other PRs are merged and this PR' +
+              ' PR is rebased.',
+            )
           # nil is prompt, true is always, false is never
-          if @pr_autostack.nil?
+          elsif @pr_autostack.nil?
             $stdout.print(
               'It looks like this is a subfeature, would you like to base ' +
               "this PR on #{base}? [y/n] ",
             )
             ans = $stdin.gets.strip
-            args += ['--base', base] if %w{Y y}.include?(ans)
+            args.unshift('--base', base) if %w{Y y}.include?(ans)
           elsif @pr_autostack
-            args += ['--base', base]
+            args.unshift('--base', base)
           end
         end
+        # <org>:<branch> is the GH API syntax for:
+        #   look for a branch of name <branch>, from a fork in owner <org>
+        args.unshift('--head', "#{push_org}:#{curr}")
         SugarJar::Log.trace("Running: gh pr create #{args.join(' ')}")
         system(which('gh'), 'pr', 'create', *args)
       else
@@ -482,6 +491,10 @@ class SugarJar
       end
     end
 
+    def extract_repo(repo)
+      File.basename(repo, '.git')
+    end
+
     def forked_repo(repo, username)
       repo = if repo.start_with?('http', 'git@')
                File.basename(repo)
@@ -898,15 +911,21 @@ class SugarJar
     end
 
     def tracked_branch(fallback: true)
+      branch = nil
       s = git_nofail(
         'rev-parse', '--abbrev-ref', '--symbolic-full-name', '@{u}'
       )
       if s.error?
-        fallback ? most_main : nil
-
+        branch = fallback ? most_main : nil
+        SugarJar::Log.debug("No specific tracked branch, using #{branch}")
       else
-        s.stdout.strip
+        branch = s.stdout.strip
+        SugarJar::Log.debug(
+          "Using explicit tracked branch: #{branch}, use " +
+          '`git branch -u` to change',
+        )
       end
+      branch
     end
 
     def most_main
@@ -937,6 +956,12 @@ class SugarJar
       @remote
     end
 
+    # Whatever org we push to, regardless of if this is a fork or not
+    def push_org
+      url = git('remote', 'get-url', 'origin').stdout.strip
+      extract_org(url)
+    end
+
     def branch_from_ref(ref, type = :local)
       # local branches are refs/head/XXXX
       # remote branches are refs/remotes/<remote>/XXXX
