@@ -9,6 +9,8 @@ class SugarJar
       'github_cli' => 'auto',
       'github_user' => ENV.fetch('USER'),
       'fallthru' => true,
+      'pr_autofill' => true,
+      'pr_autostack' => nil,
     }.freeze
 
     def self._find_ordered_files
